@@ -1,30 +1,32 @@
-#
-# The Qubes OS Project, http://www.qubes-os.org
+# The Qubes OS Project, https://www.qubes-os.org/
 #
 # Copyright (C) 2011  Tomasz Sterna <tomek@xiaoka.com>
 #
-# This program is free software; you can redistribute it and/or
-# modify it under the terms of the GNU General Public License
-# as published by the Free Software Foundation; either version 2
-# of the License, or (at your option) any later version.
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 #
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
-# You should have received a copy of the GNU Lesser General Public License along
-# with this program; if not, see <http://www.gnu.org/licenses/>.
-#
+# You should have received a copy of the GNU General Public License along
+# with this program; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
 import datetime
 import re
 
-from PyQt5 import QtCore, QtGui, QtWidgets  # pylint: disable=import-error
+from PyQt6 import QtCore, QtGui, QtWidgets  # pylint: disable=import-error
 import qubesadmin.firewall
 
 from . import ui_newfwruledlg  # pylint: disable=no-name-in-module
+# this is needed for icons to actually work
+# pylint: disable=unused-import, no-name-in-module
+from . import resources
 
 
 class FirewallModifiedOutsideError(ValueError):
@@ -39,13 +41,17 @@ class NewFwRuleDlg(QtWidgets.QDialog, ui_newfwruledlg.Ui_NewFwRuleDlg):
         self.set_ok_state(False)
         self.addressComboBox.editTextChanged.connect(
             self.address_editing_finished)
-        self.serviceComboBox.setValidator(QtGui.QRegExpValidator(
-            QtCore.QRegExp("[a-z][a-z0-9-]+|[0-9]+(-[0-9]+)?",
-                           QtCore.Qt.CaseInsensitive), None))
+        self.serviceComboBox.setValidator(QtGui.QRegularExpressionValidator(
+            QtCore.QRegularExpression(
+                "[a-z][a-z0-9-]+|[0-9]+(-[0-9]+)?",
+                QtCore.QRegularExpression.PatternOption.CaseInsensitiveOption),
+            None))
         self.serviceComboBox.setEnabled(False)
-        self.serviceComboBox.setInsertPolicy(QtWidgets.QComboBox.InsertAtBottom)
+        self.serviceComboBox.setInsertPolicy(
+            QtWidgets.QComboBox.InsertPolicy.InsertAtBottom)
         self.populate_combos()
-        self.serviceComboBox.setInsertPolicy(QtWidgets.QComboBox.InsertAtTop)
+        self.serviceComboBox.setInsertPolicy(
+            QtWidgets.QComboBox.InsertPolicy.InsertAtTop)
 
         self.model = None
 
@@ -142,7 +148,8 @@ class NewFwRuleDlg(QtWidgets.QDialog, ui_newfwruledlg.Ui_NewFwRuleDlg):
         self.set_ok_state(True)
 
     def set_ok_state(self, ok_state):
-        ok_button = self.buttonBox.button(QtWidgets.QDialogButtonBox.Ok)
+        ok_button = self.buttonBox.button(
+            QtWidgets.QDialogButtonBox.StandardButton.Ok)
         if ok_button is not None:
             ok_button.setEnabled(ok_state)
 
@@ -191,7 +198,7 @@ class QubesFirewallRulesModel(QtCore.QAbstractItemModel):
         self.__children = None  # list of rules in the FW
 
     def sort(self, idx, order):
-        rev = order == QtCore.Qt.AscendingOrder
+        rev = order == QtCore.Qt.SortOrder.AscendingOrder
         self.children.sort(key=lambda x: self.get_column_string(idx, x),
                            reverse=rev)
 
@@ -247,7 +254,6 @@ class QubesFirewallRulesModel(QtCore.QAbstractItemModel):
 
         allow_dns = False
         allow_icmp = False
-        common_action = None
 
         reversed_rules = reversed(vm.firewall.rules)
         last_rule = next(reversed_rules, None)
@@ -416,16 +422,17 @@ class QubesFirewallRulesModel(QtCore.QAbstractItemModel):
         parent_item = index.internalPointer()
         return parent_item is None
 
-    def data(self, index, role=QtCore.Qt.DisplayRole):
-        if index.isValid() and role == QtCore.Qt.DisplayRole:
+    def data(self, index, role=QtCore.Qt.ItemDataRole.DisplayRole):
+        if index.isValid() and role == QtCore.Qt.ItemDataRole.DisplayRole:
             return self.get_column_string(index.column(),
                                           self.children[index.row()])
 
     # pylint: disable=invalid-name
-    def headerData(self, section, orientation, role=QtCore.Qt.DisplayRole):
+    def headerData(self, section, orientation,
+                   role=QtCore.Qt.ItemDataRole.DisplayRole):
         if section < len(self.__column_names) \
-                and orientation == QtCore.Qt.Horizontal \
-                and role == QtCore.Qt.DisplayRole:
+                and orientation == QtCore.Qt.Orientation.Horizontal \
+                and role == QtCore.Qt.ItemDataRole.DisplayRole:
             return self.__column_names[section]
 
     @property
